/*
** Module   : SOAPFactory.java
** Abstract : Factory of SOAP objects. 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130216 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Adds support for the {@link #createSOAPHeader CREATE SOAP-HEADER} and  
 * {@link #createSOAPHeaderEntry(handle) CREATE SOAP-HEADER-ENTRYREF} language statements. 
 */
public class SOAPFactory
{
   /**
    * Create a SOAP-HEADER object and save it in the given handle.
    * 
    * @param    h
    *           A handle variable, field or class member where the SOAP-HEADER will be saved. 
    */
   public static void createSOAPHeader(handle h)
   {
      createSOAPHeader(h, (character) null);
   }

   /**
    * Create a SOAP-HEADER object, save it in the given handle and register it in the given 
    * named widget-pool.
    * 
    * @param    h
    *           A handle variable, field or class member where the SOAP-HEADER will be saved.
    * @param    pool
    *           The name of a widget-pool. May not be <code>null</code>. 
    */
   public static void createSOAPHeader(handle h, String pool)
   {
      createSOAPHeader(h, new character(pool));
   }

   /**
    * Create a SOAP-HEADER object, save it in the given handle and register it in the given 
    * named widget-pool.
    * 
    * @param    h
    *           A handle variable, field or class member where the SOAP-HEADER will be saved.
    * @param    pool
    *           The name of a widget-pool. May not be <code>null</code>. 
    */
   public static void createSOAPHeader(handle h, character pool)
   {
      // TODO: register with widget-pool
      h.assign(new SOAPHeaderImpl());
   }

   /**
    * Create a SOAP-HEADER-ENTRYREF object and save it in the given handle.
    * 
    * @param    h
    *           A handle variable, field or class member where the SOAP-HEADER-ENTRYREF will be 
    *           saved.
    * @param    pool
    *           The name of a widget-pool. May not be <code>null</code>. 
    */
   public static void createSOAPHeaderEntry(handle h)
   {
      createSOAPHeader(h, (character) null);
   }

   /**
    * Create a SOAP-HEADER-ENTRYREF object, save it in the given handle and register it in the  
    * given named widget-pool.
    * 
    * @param    h
    *           A handle variable, field or class member where the SOAP-HEADER-ENTRYREF will be 
    *           saved.
    * @param    pool
    *           The name of a widget-pool. May not be <code>null</code>. 
    */
   public static void createSOAPHeaderEntry(handle h, String pool)
   {
      createSOAPHeaderEntry(h, new character(pool));
   }


   /**
    * Create a SOAP-HEADER-ENTRYREF object, save it in the given handle and register it in the  
    * given named widget-pool.
    * 
    * @param    h
    *           A handle variable, field or class member where the SOAP-HEADER-ENTRYREF will be 
    *           saved.
    * @param    pool
    *           The name of a widget-pool. May not be <code>null</code>. 
    */
   public static void createSOAPHeaderEntry(handle h, character pool)
   {
      // TODO: register with widget-pool
      h.assign(new SOAPHeaderEntryImpl());
   }
}
